# for 0.0.96.11.0.255 События связанные с напряжением СТО 34.01-5.1-006-2021 таблица Д.1
VOLTAGE_1 = "Фаза А - пропадание напряжения"
VOLTAGE_2 = "Фаза А - восстановление напряжения"
VOLTAGE_3 = "Фаза В - пропадание напряжения"
VOLTAGE_4 = "Фаза В - восстановление напряжения"
VOLTAGE_5 = "Фаза С - пропадание напряжения"
VOLTAGE_6 = "Фаза С - восстановление напряжения"
VOLTAGE_7 = "Превышение напряжения любой фазы"
VOLTAGE_8 = "Окончание перенапряжения любой фазы"
VOLTAGE_9 = "Низкое напряжение любой фазы - начало"
VOLTAGE_10 = "Низкое напряжение любой фазы - окончание"
VOLTAGE_11 = "Превышение коэффициента несимметрии напряжений по обратной последовательности - начало"
VOLTAGE_12 = "Превышение коэффициента несимметрии напряжений по обратной последовательности - окончание"
VOLTAGE_13 = "Фаза А - перенапряжение начало"
VOLTAGE_14 = "Фаза А - перенапряжение окончание"
VOLTAGE_15 = "Фаза В - перенапряжение начало"
VOLTAGE_16 = "Фаза В - перенапряжение окончание"
VOLTAGE_17 = "Фаза С - перенапряжение начало"
VOLTAGE_18 = "Фаза С - перенапряжение окончание"
VOLTAGE_19 = "Фаза А - провал начало"
VOLTAGE_20 = "Фаза А - провал окончание"
VOLTAGE_21 = "Фаза В - провал начало"
VOLTAGE_22 = "Фаза В - провал окончание"
VOLTAGE_23 = "Фаза С - провал начало"
VOLTAGE_24 = "Фаза С - провал окончание"
VOLTAGE_25 = "Неправильная последовательность фаз начало"
VOLTAGE_26 = "Неправильная последовательность фаз окончание"
VOLTAGE_27 = "Прерывание напряжения"
VOLTAGE_28 = "Восстановление напряжения"

# for current_events События связанные с током СТО 34.01-5.1-006-2021 таблица Д.2
CURRENT_1 = "Фаза А - экспорт начало"
CURRENT_2 = "Фаза А - экспорт окончание"
CURRENT_3 = "Фаза В - экспорт начало"
CURRENT_4 = "Фаза В - экспорт окончание"
CURRENT_5 = "Фаза С - экспорт начало"
CURRENT_6 = "Фаза С - экспорт окончание"
CURRENT_7 = "Обрыв трансформатора тока фазы А"
CURRENT_8 = "Восстановление трансформатора тока фазы А"
CURRENT_9 = "Обрыв трансформатора тока фазы В"
CURRENT_10 = "Восстановление трансформатора тока фазы В"
CURRENT_11 = "Обрыв трансформатора тока фазы С"
CURRENT_12 = "Восстановление трансформатора тока фазы С"
CURRENT_13 = "Разбаланс токов - начало"
CURRENT_14 = "Разбаланс токов - окончание"
CURRENT_15 = "Замыкание трансформатора тока — начало"
CURRENT_16 = "Окончание замыкания трансформатора тока"
CURRENT_17 = "Превышение тока любой фазы - начало"
CURRENT_18 = "Окончание превышения тока любой фазы"
CURRENT_19 = "Фаза А-наличие тока при отсутствии напряжения начало"
CURRENT_20 = "Фаза А-наличие тока при отсутствии напряжения окончание"
CURRENT_21 = "Фаза В - наличие тока при отсутствии напряжения начало"
CURRENT_22 = "Фаза В - наличие тока при отсутствии напряжения окончание"
CURRENT_23 = "Фаза С - наличие тока при отсутствии напряжения начало"
CURRENT_24 = "Фаза С - наличие тока при отсутствии напряжения окончание"
CURRENT_25 = "Фаза А - превышение максимального тока начало"
CURRENT_26 = "Фаза А - превышение максимального тока окончание"
CURRENT_27 = "Фаза В - превышение максимального тока начало"
CURRENT_28 = "Фаза В - превышение максимального тока окончание"
CURRENT_29 = "Фаза С - превышение максимального тока начало"
CURRENT_30 = "Фаза С - превышение максимального тока окончание"
CURRENT_31 = "Наличие тока при отсутствии напряжения обрыв нейтрали – начало"
CURRENT_32 = "Наличие тока при отсутствии напряжения обрыв нейтрали - окончание"
CURRENT_33 = "Обратный поток мощности экспорт тока в однонаправленном счётчике - начало"
CURRENT_34 = "Обратный поток мощности экспорт тока в однонаправленном счётчике - конец"
CURRENT_35 = "Разнонаправленная мощность по фазам в трёхфазном и однофазном двухэлементном счётчике - начало"
CURRENT_36 = "Разнонаправленная мощность по фазам в трёхфазном и однофазном двухэлементном счётчике - окончание"
CURRENT_37 = "Наличие тока при выключенном реле нагрузки – начало"
CURRENT_38 = "Наличие тока при выключенном реле нагрузки – окончание"

# for 0.0.96.11.2.255 События связанные с включением/выключением ПУ. коммутации реле нагрузки СТО 34.01-5.1-006-2021 таблица Д.3
COMMUTATION_1 = "Выключение питания ПУ"
COMMUTATION_2 = "Включение питания ПУ"
COMMUTATION_3 = "Выключение абонента дистанционное"
COMMUTATION_4 = "Включение абонента дистанционное"
COMMUTATION_5 = "Получение разрешения на включение абоненту"
COMMUTATION_6 = "Выключение реле нагрузки абонентом"
COMMUTATION_7 = "Включение реле нагрузки абонентом"
COMMUTATION_8 = "Выключение локальное по превышению лимита мощности"
COMMUTATION_9 = "Выключение локальное по превышению максимального тока"
COMMUTATION_10 = "Выключение локальное при воздействии магнитного поля"
COMMUTATION_11 = "Выключение локальное по превышению напряжения"
COMMUTATION_12 = "Включение локальное при возвращение напряжения в норму"
COMMUTATION_13 = "Выключение локальное по наличию тока при отсутствии напряжения"
COMMUTATION_14 = "Выключение локальное по разбалансу токов"
COMMUTATION_15 = "Выключение локальное по температуре"
COMMUTATION_16 = "Включение резервного питания"
COMMUTATION_17 = "Отключение резервного питания"
COMMUTATION_18 = "Выключение локальное при вскрытии клеммной крышки или корпуса"
COMMUTATION_19 = "Выключение реле при превышении лимитов энергии по тарифам"
COMMUTATION_20 = "Включение реле после выключения по причине превышения активной мощности"
COMMUTATION_21 = "Включение реле после выключения по причине превышения тока"
COMMUTATION_22 = "Включение реле после выключения по причине превышения небаланса токов"
COMMUTATION_23 = "Включение реле после возвращения температуры в норму"
COMMUTATION_24 = "Включение реле после возвращения магнитного поля в норму"
COMMUTATION_25 = "Выключение реле через арбитр"
COMMUTATION_26 = "Включение реле через арбитр"
COMMUTATION_27 = "Включение реле через физический блокиратор"
COMMUTATION_28 = "Выключение реле через физический блокиратор"
COMMUTATION_29 = "Полное пропадание питания ПУ"

# for 0.0.96.11.3.255 События программирования параметров ПУ СТО 34.01-5.1-006-2021 таблица Д.4
PROGRAMING_1 = "Изменение адреса или скорости обмена RS-485-1"
PROGRAMING_2 = "Изменение адреса или скорости обмена RS-485-2"
PROGRAMING_3 = "Установка времени"
PROGRAMING_4 = "Изменение параметров перехода на летнее время"
PROGRAMING_5 = "Изменение сезонного профиля тарифного расписания ТР"
PROGRAMING_6 = "Изменение недельного профиля ТР"
PROGRAMING_7 = "Изменение суточного профиля ТР"
PROGRAMING_8 = "Изменение даты активации ТР"
PROGRAMING_9 = "Активация ТР"
PROGRAMING_10 = "Изменение расчетного дня-часа РДЧ"
PROGRAMING_11 = "Изменение режима индикации параметры"
PROGRAMING_12 = "Изменение режима индикации автопереключение"
PROGRAMING_13 = "Изменение пароля низкой секретности на чтение"
PROGRAMING_14 = "Изменение пароля высокой секретности на запись"
PROGRAMING_15 = "Изменение данных точки учета"
PROGRAMING_16 = "Изменение коэффициента трансформации по току"
PROGRAMING_17 = "Изменение коэффициента трансформации по напряжению"
PROGRAMING_18 = "Изменение параметров линии для вычисления потерь в ЛЭП"
PROGRAMING_19 = "Изменение лимита мощности для отключения"
PROGRAMING_20 = "Изменение интервала времени на отключение по мощности"
PROGRAMING_21 = "Изменение интервала времени на отключение по превышению максимального тока"
PROGRAMING_22 = "Изменение интервала времени на отключение по максимальному напряжению"
PROGRAMING_23 = "Изменение интервала времени на отключение по воздействию магнитного поля"
PROGRAMING_24 = "Изменение порога для фиксации перерыва в питании"
PROGRAMING_25 = "Изменение порога для фиксации перенапряжения"
PROGRAMING_26 = "Изменение порога для фиксации провала напряжения"
PROGRAMING_27 = "Изменение порога для фиксации превышения тангенса"
PROGRAMING_28 = "Изменение порога для фиксации коэффициента несимметрии напряжений"
PROGRAMING_29 = "Изменение согласованного напряжения"
PROGRAMING_30 = "Изменение интервала интегрирования пиковой мощности"
PROGRAMING_31 = "Изменение периода захвата профиля PROGRAMING_1 ="
PROGRAMING_32 = "Изменение периода захвата профиля 2"
PROGRAMING_33 = "Изменение режима подсветки LCD"
PROGRAMING_34 = "Изменение режима телеметрии 1"
PROGRAMING_35 = "Очистка месячного журнала"
PROGRAMING_36 = "Очистка суточного журнала"
PROGRAMING_37 = "Очистка журнала напряжения"
PROGRAMING_38 = "Очистка журнала тока"
PROGRAMING_39 = "Очистка журнала вкл/выкл"
PROGRAMING_40 = "Очистка журнала внешних воздействий"
PROGRAMING_41 = "Очистка журнала соединений"
PROGRAMING_42 = "Очистка журнала несанкционированного доступа"
PROGRAMING_43 = "Очистка журнала качества сети"
PROGRAMING_44 = "Очистка журнала тангенса"
PROGRAMING_45 = "Очистка журнала входов/выходов"
PROGRAMING_46 = "Очистка профиля 1"
PROGRAMING_47 = "Очистка профиля 2"
PROGRAMING_48 = "Очистка профиля 3"
PROGRAMING_49 = "Изменение таблицы специальных дней"
PROGRAMING_50 = "Изменение режима управления реле"
PROGRAMING_51 = "Фиксация показаний в месячном журнале"
PROGRAMING_52 = "Изменение режима инициативного выхода"
PROGRAMING_53 = "Изменение одноадресного ключа для низкой секретности"
PROGRAMING_54 = "Изменение широковещательного ключа шифрования для низкой секретности"
PROGRAMING_55 = "Изменение одноадресного ключа для высокой секретности"
PROGRAMING_56 = "Изменение широковещательного ключа для высокой секретности"
PROGRAMING_57 = "Изменение ключа аутентификации для высокой секретности"
PROGRAMING_58 = "Изменение мэстер-ключа"
PROGRAMING_59 = "Изменение уровня преобразования для низкой секретности"
PROGRAMING_60 = "Изменение уровня преобразования для высокой секретности"
PROGRAMING_61 = "Изменение номера дистанционного дисплея"
PROGRAMING_62 = "Изменение режима учета активной энергии по модулю или раздельно в двух направлениях"
PROGRAMING_63 = "Установка времени по GPS/ГЛОНАСС"
PROGRAMING_64 = "Изменение режима отключения по обрыву нейтрали"
PROGRAMING_65 = "Обновление ПО"
PROGRAMING_66 = "Изменение режима отключения по разбалансу токов"
PROGRAMING_67 = "Изменение режима отключения по температуре"
PROGRAMING_68 = "Коррекция времени"
PROGRAMING_69 = "Изменение ключа аутентификации для низкой секретности"
PROGRAMING_70 = "Очистка флагов инициативного выхода"
PROGRAMING_71 = "Изменение таймаута для HDLC-соединения"
PROGRAMING_72 = "Изменение часов болъших нагрузок"
PROGRAMING_73 = "Изменение часов контроля максимума"
PROGRAMING_74 = "Изменение схемы подключения"
PROGRAMING_75 = "Изменение режима телеметрии 2"
PROGRAMING_76 = "Изменение режима телеметрии 3"
PROGRAMING_77 = "Изменение режима телеметрии 4"
PROGRAMING_78 = "Изменение режима отключения при вскрытии клеммной крышки или корпуса"
PROGRAMING_79 = "Изменение настройки активного коммуникационного профиля для портов связи"
PROGRAMING_80 = "Очистка журнала качества сети на месячном интервале"
PROGRAMING_81 = "Изменение интервала интегрирования параметров сети"
PROGRAMING_82 = "Изменение порогового значения по времени. Коэффициент реактивной мощности tg <р средний по всем фазам"
PROGRAMING_83 = "Изменение порогового значения по времени. Дифференциальньм ток. % от величины наибольшего ток"
PROGRAMING_84 = "Изменение порогового значения по времени. Коэффициент несимметрии по обратной последовательности"
PROGRAMING_85 = "Изменение адреса или скорости обмена Оптопорт Р1"
PROGRAMING_86 = "Изменение адреса или скорости обмена Порт Р4"
PROGRAMING_87 = "Изменение фильтра событий отключения реле нагрузки"
PROGRAMING_88 = "Изменение монитора событий реле нагрузки"
PROGRAMING_89 = "Изменение настройки учёта энергии"
PROGRAMING_90 = "Изменение порогового значения отклонения частоты"
PROGRAMING_91 = "Изменение порогового значения контроля активной мощности на интервале интегрирования"
PROGRAMING_92 = "Изменение порогового значения контроля активной мощности на интервале интегрирования в часы пиковых нагрузок"
PROGRAMING_93 = "Изменение времени фиксации стоп кадра. Фиксация стоп кадра"
PROGRAMING_94 = "Монитор событий реле нагрузки"
PROGRAMING_95 = "Монитор событий реле сигнализации 1"
PROGRAMING_96 = "Монитор событий реле сигнализации 2"
PROGRAMING_97 = "Монитор событий реле сигнализации 3"
PROGRAMING_98 = "Монитор событий реле сигнализации 4"
PROGRAMING_99 = "Изменение параметров арбитра реле нагрузки"
PROGRAMING_100 = "Изменение параметров арбитра реле сигнализации 1"
PROGRAMING_101 = "Изменение параметров арбитра реле сигнализации 2"
PROGRAMING_102 = "Изменение параметров арбитра реле сигнализации 3"
PROGRAMING_103 = "Изменение параметров арбитра реле сигнализации 4"
PROGRAMING_104 = "Изменение фильтра событий реле сигнализации 1"
PROGRAMING_105 = "Изменение фильтра событий реле сигнализации 2"
PROGRAMING_106 = "Изменение фильтра событий реле сигнализации 3 "
PROGRAMING_107 = "Изменение фильтра событий реле сигнализации 4"
PROGRAMING_108 = "Изменение режима управления реле сигнализации 1"
PROGRAMING_109 = "Изменение режима управления реле сигнализации 2"
PROGRAMING_110 = "Изменение режима управления реле сигнализации 3"
PROGRAMING_111 = "Изменение режима управления реле сигнализации 4"
PROGRAMING_112 = "Изменение типа контакта реле сигнализации"
PROGRAMING_113 = "Изменение таймаута для TCP/UDP соединения (Оптопорт P1)"
PROGRAMING_114 = "Изменение таймаута для TCP/UDP соединения (Порт P2)"
PROGRAMING_115 = "Изменение таймаута для TCP/UDP соединения (Порт P3)"
PROGRAMING_116 = "Изменение таймаута для TCP/UDP соединения (Порт P4)"
PROGRAMING_117 = "Очистка журнала «выхода тангенса за порог на интервале интегрирования»"
PROGRAMING_118 = "Очистка журнала «коррекции времени»"
PROGRAMING_119 = "Очистка журнала «На начало года»"
PROGRAMING_120 = "Резерв"
PROGRAMING_121 = "Очистка журнала «Контроля мощности»"
PROGRAMING_122 = "Очистка журнала «Батареи»"
PROGRAMING_123 = "Очистка журнала «Контроль блокиратора реле нагрузки»"
PROGRAMING_124 = "Очистка журнала «Контроль температуры»"
PROGRAMING_125 = "Очистка журнала «Отклонение напряжения фазы А»"
PROGRAMING_126 = "Очистка журнала «Отклонение напряжения фазы B»"
PROGRAMING_127 = "Очистка журнала «Отклонение напряжения фазы C»"
PROGRAMING_128 = "Очистка журнала «Отклонение линейного напряжения AB»"
PROGRAMING_129 = "Очистка журнала «Отклонение линейного напряжения BC»"
PROGRAMING_130 = "Очистка журнала «Отклонение линейного напряжения CA»"
PROGRAMING_131 = "Очистка журнала «Превышение напряжения»"
PROGRAMING_132 = "Очистка журнала «Прерывание напряжения»"
PROGRAMING_133 = "Очистка журнала «Телесигнализация»"
PROGRAMING_134 = "Очистка журнала «Нештатная ситуация сети»"
PROGRAMING_135 = "Изменение порога напряжения по нулевой последовательности, время до срабатывания события, с (нештатная ситуация сети)"
PROGRAMING_136 = "Изменение порога напряжения по нулевой последовательности, время задержки установки события PUSH, с (нештатная ситуация сети)"
PROGRAMING_137 = "Изменение порога напряжения, минимальное значение, В(нештатная ситуация сети)"
PROGRAMING_138 = "Изменение порога напряжения, время до срабатывания события, с(нештатная ситуация сети)"
PROGRAMING_139 = "Изменение порога напряжения, время задержки установки события PUSH, с (нештатная ситуация сети)"
PROGRAMING_140 = "Изменение порога напряжения по обратной последовательности, максимальное значение, В (нештатная ситуация сети)"
PROGRAMING_141 = "Изменение порога напряжения по обратной последовательности, время до срабатывания события, с (нештатная ситуация сети)"
PROGRAMING_142 = "Изменение порога напряжения по обратной последовательности, время задержки установки события PUSH, с (нештатная ситуация сети)"
PROGRAMING_143 = "Обжатие электронных пломб"
PROGRAMING_144 = "Очистка фиксации событий воздействия магнитного и/или ВЧ поля"
PROGRAMING_145 = "Изменение часового пояса"
PROGRAMING_146 = "Изменение последовательности вывода на ЖКИ в режиме «Автопрокрутка»"
PROGRAMING_147 = "Изменение последовательности вывода на ЖКИ в режиме «По кнопке»"
PROGRAMING_148 = "Изменение уровня лимита по току"
PROGRAMING_149 = "Изменение уровня лимита по напряжению"
PROGRAMING_150 = "Номер аварийного тарифа"
PROGRAMING_1024 = "КПЗ. Изменение конфигурации ПУ"

# for 0.0.96.11.4.255 События внешних воздействий СТО 34.01-5.1-006-2021 таблица Д.5
EXTERNAL_IMPACT_1 = "Магнитное поле - начало"
EXTERNAL_IMPACT_2 = "Магнитное поле - окончание"
EXTERNAL_IMPACT_3 = "Срабатывание электронной пломбы крышки клеммников"
EXTERNAL_IMPACT_4 = "Срабатывание электронной пломбы корпуса"
EXTERNAL_IMPACT_5 = "Срабатывание электронной пломбы внешнего датчика"
EXTERNAL_IMPACT_6 = "Воздействие ВЧ поля - начало"
EXTERNAL_IMPACT_7 = "Воздействие ВЧ поля- окончание"

# for 0.0.96.11.5.255 Коммуникационные события СТО 34.01-5.1-006-2021 таблица Д.6
COMMUNICATION_1 = "Разорвано соединение интерфейс"
COMMUNICATION_2 = "Установлено соединение интерфейс"

# for 0.0.96.11.6.255 События контроля доступа СТО 34.01-5.1-006-2021 таблица Д.7
ACCESS_1 = "Попытка несанкционированного доступа интерфейс"
ACCESS_2 = "Нарушение требований протокола"
ACCESS_3 = "Блокировка по превышению количества неправильных паролей"
ACCESS_4 = "Ошибка верификации прошивки"

# for 0.0.96.11.7.255 Коды событий для журнала самодиагностики СТО 34.01-5.1-006-2021 таблица Д.8
SELF_DIAGNOSTIC_1 = "Инициализация ПУ"
SELF_DIAGNOSTIC_2 = "Измерительный блок — ошибка"
SELF_DIAGNOSTIC_3 = "Измерительный блок — норма"
SELF_DIAGNOSTIC_4 = "Вычислительный блок — ошибка"
SELF_DIAGNOSTIC_5 = "Часы реального времени — ошибка"
SELF_DIAGNOSTIC_6 = "Часы реального времени — норма"
SELF_DIAGNOSTIC_7 = "Блок питания — ошибка"
SELF_DIAGNOSTIC_8 = "Блок питания — норма"
SELF_DIAGNOSTIC_9 = "Дисплей — ошибка"
SELF_DIAGNOSTIC_10 = "Дисплей — норма"
SELF_DIAGNOSTIC_11 = "Блок памяти — ошибка"
SELF_DIAGNOSTIC_12 = "Блок памяти — норма"
SELF_DIAGNOSTIC_13 = "Блок памяти программ — ошибка"
SELF_DIAGNOSTIC_14 = "Блок памяти программ — норма"
SELF_DIAGNOSTIC_15 = "Система тактирования ядра — ошибка"
SELF_DIAGNOSTIC_16 = "Система тактирования ядра — норма"
SELF_DIAGNOSTIC_17 = "Система тактирования часов — ошибка"
SELF_DIAGNOSTIC_18 = "Система тактирования часов — норма"
SELF_DIAGNOSTIC_19 = "Вычислительный блок — норма"

# for 0.0.96.11.8.255 События по превышению реактивной мощности tg ф тангенс сети СТО 34.01-5.1-006-2021 таблица Д.9
REACTIVE_POWER_1 = "Превышение установленного порога — начало"
REACTIVE_POWER_2 = "Превышение установленного порога — окончание"

# for 0.0.96.5.1.255 Статус качества сети профиль суточных показаний
POWER_QUALITY1_1 = "Отклонение напряжения более чем на 10% от номинала"
POWER_QUALITY1_2 = "Отклонение частоты более чем на 04 Гц от номинала"

# for POWER_QUALITY1_0 =.0.96.5.4.255 Статус качества сети журнал качества сети
POWER_QUALITY2_1 = "Снижение напряжения более чем на 10%"
POWER_QUALITY2_8 = "Повышение напряжения более чем на 10%"
POWER_QUALITY2_0x10 = "Снижение частоты более чем на 04 Гц"
POWER_QUALITY2_0x20 = "Снижение частоты более чем на 02 Гц"
POWER_QUALITY2_0x40 = "Увеличение частоты более чем на 02 Гц"
POWER_QUALITY2_0x80 = "Увеличение частоты более чем на 04 Гц"
POWER_QUALITY2_0x4000 = "Снижение частоты более, чем на заданный порог"
POWER_QUALITY2_0x8000 = "Увеличение частоты более, чем на заданный порог"
