OPTICAL_PORT = "Optical port"
RS485 = "RS-485"
TCP_IP = "TCP/IP"
NOT_DEFINED = "not defined"
INTERNAL_CRYSTAL = "internal crystal"
MAINS_FREQUENCY_50_HZ = "mains frequency 50 Hz"
MAINS_FREQUENCY_60_HZ = "mains frequency 60 Hz"
GPS_GLOBAL_POSITIONING_SYSTEM = "GPS (global positioning system)"
RADIO_CONTROLLED = "radio controlled"
CONTROL_MODE_0 = "None. The disconnect control object is always in <connected> state"
CONTROL_MODE_1 = "Disconnection: remote(b, c), manual(f), local(g) Reconnection: remote(d), manual(e)"
CONTROL_MODE_2 = "Disconnection: remote(b, c), manual(f), local(g) Reconnection: remote(a), manual(e)"
CONTROL_MODE_3 = "Disconnection: remote(b, c), local(g) Reconnection: Remote(d), manual(e)"
CONTROL_MODE_4 = "Disconnection: remote(b, c), local(g) Reconnection: Remote(a), manual(e)"
CONTROL_MODE_5 = "Disconnection: remote(b, c), manual(f), local(g) Reconnection: remote(d), manual(e), local(h)"
CONTROL_MODE_6 = "Disconnection: remote(b, c), local(g) Reconnection: remote(d), manual(e), local(h)"
RU_CONTROL_MODE_129 = "Disconnection: remote(b, c), manual(f), local(m) Reconnection: remote(d), manual(e)"
RU_CONTROL_MODE_130 = "Disconnection: remote(b, c), manual(f), local(m) Reconnection: remote(a), manual(e)"
RU_CONTROL_MODE_131 = "Disconnection: remote(b, c), local(m) Reconnection: remote(d), manual(e)"
RU_CONTROL_MODE_132 = "Disconnection: remote(b, c), local(m) Reconnection: remote(a)"
RU_CONTROL_MODE_133 = "Disconnection: remote(b, c), local(m) Reconnection: remote(a), local(k)"
RU_CONTROL_MODE_134 = "Disconnection: remote(b, c), local(m, s) Reconnection: remote(d), manual(e), local(p)"
DISCONNECTED = "Disconnected"
CONNECTED = "Connected"
READY_FOR_RECONNECTION = "Ready for reconnection"
NOT_REGISTERED = "not registered"
REGISTERED_HOME_NETWORK = "registered, home network"
NOT_REGISTERED_BUT_MT = "not registered, but MT is currently searching a new operator to register to"
REGISTRATION_DENIED = "registration denied"
UNKNOWN = "unknown"
REGISTERED_ROAMING = "registered, roaming"
INACTIVE = "inactive"
INCOMING_CALL = "incoming call"
ACTIVE = "active"
GPRS = "GPRS"
EDGE = "EDGE"
UMTS = "UMTS"
HSDPA = "HSDPA"
BAUD_300 = "300 baud"
BAUD_600 = "600 baud"
BAUD_1200 = "1200 baud"
BAUD_2400 = "2400 baud"
BAUD_4800 = "4800 baud"
BAUD_9600 = "9600 baud"
BAUD_19200 = "19200 baud"
BAUD_38400 = "38400 baud"
BAUD_57600 = "57600 baud"
BAUD_115200 = "115200 baud"
IMAGE_TRANSFER_NOT_INITIATED = "Image transfer not initiated"
IMAGE_TRANSFER_INITIATED = "Image transfer initiated"
IMAGE_VERIFICATION_INITIATED = "Image verification initiated"
IMAGE_VERIFICATION_SUCCESSFUL = "Image verification successful"
IMAGE_VERIFICATION_FAILED = "Image verification failed"
IMAGE_ACTIVATION_INITIATED = "Image activation initiated"
IMAGE_ACTIVATION_SUCCESSFUL = "Image activation successful"
IMAGE_ACTIVATION_FAILED = "Image activation failed"
FIFO = "fifo (first in first out)"
LIFO = "lifo (last in first out)"
LARGEST = "largest"
SMALLEST = "smallest"
NEAREST_TO_ZERO = "nearest to zero"
FAREST_FROM_ZERO = "farest from zero"
WRITE_ATTRIBUTE = "write attribute"
EXECUTE_SPECIFIC_METHOD = "execute specific method"
SCHEDULE_TYPE_1 = "size of execution time = 1; wildcard in date allowed"
SCHEDULE_TYPE_2 = "size of execution time = n; all time values are the same, wildcard in date not allowed"
SCHEDULE_TYPE_3 = "size of execution time = n; all time values are the same, wildcard in date are allowed"
SCHEDULE_TYPE_4 = "size of execution time = n; time values may be different, wildcard in date not allowed"
SCHEDULE_TYPE_5 = "size of execution time = n; time values may be different, wildcard in date are allowed"
NO_ACCESS = "no access"
READ_ONLY = "read only"
WRITE_ONLY = "write only"
READ_AND_WRITE = "read and write"
NON_ASSOCIATED = "non associated"
ASSOCIATION_PENDING = "association pending"
ASSOCIATED = "associated"
NO_STATION = "no station"
CLIENT_MANAGEMENT_PROCESS = "Client Management Process"
PUBLIC_CLIENT = "Public client"
METER_READER = "Meter Reader"
UTILITY_SETTING = "Utility Settings"
PUSH = "Push"
FIRMWARE_UPDATE = "Firmware Update"
IHD = "IHD"
NONE = "NONE"
LOW = "LOW"
HIGH = "HIGH"
HIGH_MD5 = "HIGH MD5"
HIGH_SHA1 = "HIGH SHA1"
HIGH_GMAC = "HIGH GMAC"
HIGH_SHA256 = "HIGH SHA256"
HIGH_ECDSA = "HIGH ECDSA"
ACCESS = "access"
AUTHENTICATED_ACCESS = "authenticated_access"
NOTHING = "nothing"
ALL_MESSAGES_TO_BE_AUTHENTICATION = "all messages to be authentication"
ALL_MESSAGES_TO_BE_ENCRYPTED = "all messages to be encrypted"
ALL_MESSAGES_TO_BE_AUTH_AND_ENC = "all messages to be authentication and encrypted"
RESERVED = "reserved"
AUTHENTICATION_REQUEST = "authentication request"
ENCRYPTION = "encryption"
AUTHENTICATION_AND_ENCRYPTION = "authentication and encryption"
DIGITAL_SIGNATURE = "digital signature"
ENCRYPTED_REQUEST = "encrypted request"
DIGITALLY_SIGNED_REQUEST = "digitally signed request"
AUTHENTICATION_RESPONSE = "authentication response"
ENCRYPTED_RESPONSE = "encrypted response"
DIGITALLY_SIGNED_RESPONSE = "digitally signed response"
UNUSED = "unused, shall be set 0"
AUTHENTICATION = "authentication"
AUTHENTICATION_READ_ONLY = "authenticated_read_only"
AUTHENTICATION_WRITE_ONLY = "authenticated_write_only"
AUTHENTICATION_READ_AND_WRITE = "authenticated_read_and_write"
TIME_YEAR = "a"
TIME_MONTH = "mo"
TIME_WEEK = "wk"
TIME_DAY = "d"
TIME_HOUR = "h"
TIME_MINUTE = "min"
TIME_SECOND = "s"
PHASE_ANGLE_DEGREE = "°"
TEMPERATURE = "°C"
LOCAL_CURRENCY = "currency"
LENGTH_METRE = "m"
SPEED_METRE_PER_SECOND = "m/s"
VOLUME_VALUE_CUBIC_METRE = "m³"
CORRECTED_VOLUME_CUBIC_METRE = "m³*"
VOLUME_FLUX_CUBIC_METRE_PER_HOUR = "m³/h"
CORRECTED_VOLUME_FLUX_CUBIC_METRE_PER_HOUR = "m³/h*"
VOLUME_FLUX_CUBIC_METRE_PER_DAY = "m³/d"
CORRECTED_VOLUME_FLUX_CUBIC_METRE_PER_DAY = "m³/d"
VOLUME_LITRE = "l"
MASS_KILOGRAM = "kg"
FORCE_NEWTON = "N"
ENERGY_NEWTON_METER = "Nm"
PRESSURE_PASCAL = "Pa"
PRESSURE_BAR = "bar"
ENERGY_JOULE = "J"
THERMAL_POWER_RATE_OF_CHANGE_JOULE_PER_HOUR = "J/h"
ACTIVE_POWER_WATT = "W"
APPARENT_POWER_VOLT_AMPERE = "VA"
REACTIVE_POWER_VAR = "var"
ACTIVE_ENERGY_VALUE_WATT_HOUR = "Wh"
APPARENT_ENERGY_VALUE_VOLT_AMPERE_HOUR = "VAh"
REACTIVE_ENERGY_VALUE_VAR_HOUR = "varh"
CURRENT_AMPERE = "A"
ELECTRICAL_CHARGE_COULOMB = "C"
VOLTAGE_VOLT = "V"
ELECTRIC_FIELD_STRENGTH_VOLT_PER_METRE = "V/m"
CAPACITANCE_FARAD = "F"
RESISTANCE_OHM = "Ω"
RESISTIVITY = "Ωm²/m"
MAGNETIC_FLUX_WEBER = "Wb"
MAGNETIC_FLUX_DENSITY_TESLA = "T"
MAGNETIC_FIELD_STRENGTH_AMPERE_PER_METRE = "A/m"
INDUCTANCE_HENRY = "H"
FREQUENCY_HERTZ = "Hz"
RW_ACTIVE_ENERGY_VALUE = "1/(Wh)"
RB_REACTIVE_ENERGY_VALUE = "1/(varh)"
RS_APPARENT_ENERGY_VALUE = "1/(VAh)"
VOLT_SQUARED_HOUR_VOLT_SQUARED_HOUR_METER = "V²h"
AMPERE_SQUARED_HOUR = "A²h"
MASS_FLUX_KILOGRAM_PER_SECOND = "kg/s"
CONDUCTANCE_SIEMENS = "S, mho"
TEMPERATURE_KELVIN = "K"
RU2H_VOLT_SQUARED_HOUR_METER = "1/(V²h)"
RI2H_AMPERE_SQUARED_HOUR_METER = "1/(A²h)"
RV_METER = "1/m³"
PERCENTAGE = "%"
AMPERE_HOURS = "Ah"
ENERGY_PER_VOLUME = "Wh/m³"
CALORIFIC_VALUE_WOBBE = "J/m³"
MOLAR_FRACTION_OF_GAS_COMPOSITION_MOLE_PERCENT = "Mol %"
MASS_DENSITY_QUANTITY_OF_MATERIAL = "g/m³"
DYNAMIC_VISCOSITY_PASCAL_SECOND = "Pa s"
SPECIFIC_ENERGY_JOULE_KILOGRAM = "J/kg"
PRESSURE_GRAM_PER_SQUARE_CENTIMETER = "g/cm²"
PRESSURE_ATMOSPHERE = "atm"
SIGNAL_STRENGTH_MILLIWATT = "dBm"
SIGNAL_STRENGTH_MICROVOLT = "dbµV"
LOGARITHMIC_UNIT = "dB"
LENGTH_INCH = "in"
LENGTH_FOOT = "ft"
MASS_POUND = "lb"
TEMPERATURE_FAHRENHEIT = "°F"
TEMPERATURE_RANKINE = "°R"
AREA_SQUARE_INCH = "sq. in"
AREA_SQUARE_FOOT = "sq ft"
AREA_ACRE = "ac"
VOLUME_CUBIC_INCH = "cu in"
VOLUME_CUBIC_FOOT = "cu ft"
VOLUME_ACRE_FOOT = "ac ft"
VOLUME_GALLON_IMPERIAL = "gal(imp)"
VOLUME_GALLON_US = "gal(US)"
FORCE_POUND_FORCE = "lbf"
PRESSURE_POUND_FORCE_PER_SQUARE_INCH = "psi"
DENSITY_POUND_PER_CUBIC_FOOT = "lb/cu ft"
DYNAMIC_VISCOSITY = "lb/(ft .s)"
KINEMATIC_VISCOSITY_SQUARE_FOOT_PER_SECOND = "sq ft/s"
ENERGY_BRITISH_THERMAL_UNIT = "Btu"
ENERGY_THERM_EU = "thm(EC)"
ENERGY_THERM_US = "thm(US)"
CALORIFIC_VALUE_OF_MASS_LENTHALPY = "Btu/lb"
CALORIFIC_VALUE_OF_VOLUME_WOBBE = "Btu/cu ft"
VOLUME_METER_CUBIC_FEET_RV = "cu ft rv"
SPEED_FOOT_PER_SECOND = "ft/s"
VOLUME_FLUX_CUBIC_FOOT_PER_SECOND = "cu ft/s"
VOLUME_FLUX_CUBIC_FOOT_PER_MIN = "cu ft/min"
VOLUME_FLUX_CUBIC_FOOT_PER_HOUR = "cu ft/h"
VOLUME_FLUX_CUBIC_FOOT_PER_DAY = "cu ft/d"
VOLUME_FLUX_ACRE_FOOT_PER_SECOND = "ac ft/s"
VOLUME_FLUX_ACRE_FOOT_PER_MIN = "ac ft/min"
VOLUME_FLUX_ACRE_FOOT_PER_HOUR = "ac ft/h"
VOLUME_FLUX_ACRE_FOOT_PER_DAY = "ac ft/d"
VOLUME_IMPERIAL_GALLON_METER_RV = "gal(imp) rv"
VOLUME_FLUX_IMPERIAL_GALLON_PER_SECOND = "gal(imp)/s"
VOLUME_FLUX_IMPERIAL_GALLON_PER_MIN = "gal(imp)/min"
VOLUME_FLUX_IMPERIAL_GALLON_PER_HOUR = "gal(imp)/h"
VOLUME_FLUX_IMPERIAL_GALLON_PER_DAY = "gal(imp)/d"
VOLUME_US_GALLON_RV = "gal(US) rv"
VOLUME_FLUX_US_GALLON_PER_SECOND = "gal(US)/s"
VOLUME_FLUX_US_GALLON_PER_MIN = "gal(US)/min"
VOLUME_FLUX_US_GALLON_PER_HOUR = "gal(US)/h"
VOLUME_FLUX_US_GALLON_PER_DAY = "gal(US)/d"
ENERGY_FLOW_BRITISH_THERMAL_UNIT_PER_SECOND = "Btu/s"
ENERGY_FLOW_BRITISH_THERMAL_UNIT_PER_MINUTE = "Btu/min"
ENERGY_FLOW_BRITISH_THERMAL_UNIT_PER_HOUR = "Btu/h"
ENERGY_FLOW_BRITISH_THERMAL_UNIT_PER_DAY = "Btu/d"
EXTENDED_TABLE_OF_UNITS = "extended"
OTHER_UNIT = "other"
NO_UNIT_UNITLESS_COUNT = "count"
GUEK = "global unicast encryption key"
GBEK = "global broadcast encryption key"
GAK = "authentication key"
KEK = "master key"
AES_GCM_128 = "AES-GCM-128 for authenticated encryption and AES-128 for key wrapping"
AES_GCM_128_ECDSA_P_256 = "AES-GCM-128 authenticated encryption, ECDSA P-256 digital signature, ECDH P-256 key agreement, SHA-256 hash, V.44 compression and AES-128 key wrap"
AES_GCM_256_ECDSA_P_384 = "AES-GCM-256 authenticated encryption, ECDSA P-384 digital signature, ECDH P-384 key agreement, SHA-384 hash, V.44 compression and AES-256 key wrap"
SERVER = "server"
CLIENT_OR_THIRD_PARTY = "client or third party"
CERTIFICATION_AUTHORITY = "certification authority"
OTHER = "other"
KEY_AGREEMENT = "key agreement"
TLS = "TLS"
DIGITAL_SIGNATURE_KEY_PAIR = "digital signature key pair"
KEY_AGREEMENT_KEY_PAIR = "key agreement key pair"
TLS_KEY_PAIR = "tls key pair"
CERTIFICATE_IDENTIFICATION_ENTITY = "certificate identification entity"
CERTIFICATE_IDENTIFICATION_SERIAL = "certificate identification serial"
RESTRICTION_BY_DATE = "restriction by date"
RESTRICTION_BY_ENTRY = "restriction by entry"
TCP = "TCP"
UDP = "UDP"
FTP_RESERVED = "reserved for FTP"
SMTP_RESERVED = "reserved for SMTP"
SMS = "SMS"
HDLC = "HDLC"
M_BUS = "M_BUS"
ZIGBEE_RESERVED = "reserved for ZIGBEE"
DLMS_GATEWAY = "DLMS Gateway"
MANUFACTURER_SPECIFIC = "Manufacturer specific"
A_XDR = "A-XDR encoded xDLMS APDU"
XML = "XML encoded xDLMS APDU"
UNCONFIRMED_FAILURE = "unconfirmed, retry on supporting protocol layer failure"
UNCONFIRMED_MISSING = "unconfirmed, retry on missing supporting protocol layer confirmation"
CONFIRMED = "confirmed, retry on missing confirmation"
MASTER_KEY = "master key"
GLOB_UNI_ENCR_KEY = "global unicast encryption key"
GLOB_BROAD_ENCR_KEY = "global broadcast encryption key"
IDENTIFIED_KEY = "identified key"
WRAPPED_KEY = "wrapped key"
AGREED_KEY = "agreed key"

# for GSM_diagnostic.cell_info
OR_LESS = "or less"
OR_GREATER = "or greater"
NOT_KNOWN_OR_NOT_DETECTABLE = "not known or not detectable"
