# for 0.0.96.11.0.255 События связанные с напряжением ГОСТ Р 58940—2020 таблица Д.1
VOLTAGE_1 = "Phase L1-voltage drop"
VOLTAGE_2 = "Phase L1-voltage recovery"
VOLTAGE_3 = "Phase L2-voltage drop"
VOLTAGE_4 = "Phase L2-voltage recovery"
VOLTAGE_5 = "Phase L3-voltage drop"
VOLTAGE_6 = "Phase L3-voltage recovery"
VOLTAGE_7 = "Exceeding the voltage of any phase"
VOLTAGE_8 = "End of over voltage of any phase"
VOLTAGE_9 = "Low voltage of any phase-start"
VOLTAGE_10 = "Low voltage of any phase-end"
VOLTAGE_11 = "Excess of the voltage unbalance coefficient in the reverse sequence-the beginning"
VOLTAGE_12 = "Excess of the voltage unbalance coefficient in the reverse sequence - end"
VOLTAGE_13 = "Phase L1-over voltage start"
VOLTAGE_14 = "Phase L1-over voltage end"
VOLTAGE_15 = "Phase L2-over voltage start"
VOLTAGE_16 = "Phase L2-over voltage end"
VOLTAGE_17 = "Phase L3-over voltage start"
VOLTAGE_18 = "Phase L3-over voltage end"
VOLTAGE_19 = "Phase L1-failure start"
VOLTAGE_20 = "Phase L1-failure ending"
VOLTAGE_21 = "Phase L2-failure start"
VOLTAGE_22 = "Phase L2-failure ending"
VOLTAGE_23 = "Phase L3-failure start"
VOLTAGE_24 = "Phase L3-failure ending"
VOLTAGE_25 = "Incorrect phase sequence start"
VOLTAGE_26 = "Incorrect phase sequence ending"
VOLTAGE_27 = "Voltage interruption"
VOLTAGE_28 = "Voltage recovery"

# for current_events События связанные с током ГОСТ Р 58940—2020 таблица Д.2
CURRENT_1 = "Phase L1-export start"
CURRENT_2 = "Phase L1-Export end"
CURRENT_3 = "Phase L2-export start"
CURRENT_4 = "Phase L2-Export end"
CURRENT_5 = "Phase L3-export start"
CURRENT_6 = "Phase L3-Export end"
CURRENT_7 = "Phase L1 current transformer breakage"
CURRENT_8 = "Restoring the Phase L1 current transformer"
CURRENT_9 = "Phase L2 current transformer breakage"
CURRENT_10 = "Restoring the Phase L2 current transformer"
CURRENT_11 = "Phase L3 current transformer breakage"
CURRENT_12 = "Restoring the Phase L3 current transformer"
CURRENT_13 = "Current unbalance-the beginning"
CURRENT_14 = "Current unbalance-end"
CURRENT_15 = "Current transformer short circuit-start"
CURRENT_16 = "Current transformer short circuit termination"
CURRENT_17 = "Exceeding the current of any phase-the beginning"
CURRENT_18 = "End of excess current of any phase"
CURRENT_19 = "Phase L1-the presence of current in the absence of voltage start"
CURRENT_20 = "Phase L1-the presence of current in the absence of voltage end"
CURRENT_21 = "Phase L2-the presence of current in the absence of voltage start"
CURRENT_22 = "Phase L2-the presence of current in the absence of voltage end"
CURRENT_23 = "Phase L3-the presence of current in the absence of voltage start"
CURRENT_24 = "Phase L3-the presence of current in the absence of voltage end"
CURRENT_25 = "Phase L1-exceeding the maximum current start"
CURRENT_26 = "Phase L1-exceeding the maximum current end"
CURRENT_27 = "Phase L2-exceeding the maximum current start"
CURRENT_28 = "Phase L2-exceeding the maximum current end"
CURRENT_29 = "Phase L3-exceeding the maximum current start"
CURRENT_30 = "Phase L3-exceeding the maximum current end"
CURRENT_31 = "The presence of current in the absence of voltage neutral breakage. Begin"
CURRENT_32 = "The presence of current in the absence of voltage neutral breakage. End"
CURRENT_33 = "Reverse of the power export of current in a unidirectional counter. Begin"
CURRENT_34 = "Reverse of the power export of current in a unidirectional counter. End"
CURRENT_35 = "Unspressed phase power in a three -phase and single -phase two -element counter. Begin"
CURRENT_36 = "Unspressed phase power in a three -phase and single -phase two -element counter. End"
CURRENT_37 = "The presence of current with the load relay is turned off. Begin"
CURRENT_38 = "The presence of current with the load relay is turned off. End"


# for 0.0.96.11.2.255 События связанные с включением/выключением ПУ. коммутации реле нагрузки ГОСТ Р 58940—2020 таблица Д.3
COMMUTATION_1 = "Power down of the device"
COMMUTATION_2 = "Powering up the device"
COMMUTATION_3 = "Remote subscriber shutdown"
COMMUTATION_4 = "Enabling the subscriber remotely"
COMMUTATION_5 = "Getting permission to enable the subscriber"
COMMUTATION_6 = "Switching off the load relay by the subscriber"
COMMUTATION_7 = "Switching on the load relay by the subscriber"
COMMUTATION_8 = "Local shutdown when the power limit is exceeded"
COMMUTATION_9 = "Local shutdown when the maximum current is exceeded"
COMMUTATION_10 = "Local shutdown when exposed to a magnetic field"
COMMUTATION_11 = "Local shutdown when the voltage is exceeded"
COMMUTATION_12 = "Switching on local when the voltage returns to normal"
COMMUTATION_13 = "Local shutdown by the presence of current in the absence of voltage"
COMMUTATION_14 = "Local shutdown based on current unbalance"
COMMUTATION_15 = "Local temperature shutdown"
COMMUTATION_16 = "Enabling backup power"
COMMUTATION_17 = "Switching off the backup power supply"
COMMUTATION_18 = "Local shutdown when opening the terminal cover or housing"
COMMUTATION_19 = "Turning off the relay when the energy limits are exceeded by tariffs"
COMMUTATION_20 = "Turning on the relay after turning off due to the excess of active power"
COMMUTATION_21 = "Turning on the relay after turning off due to current excess"
COMMUTATION_22 = "Turning on the relay after turning off due to excess of the non -balance of currents"
COMMUTATION_23 = "Turning the relay after returning the temperature to normal"
COMMUTATION_24 = "The relay is turned on after the magnetic field returned to normal"
COMMUTATION_25 = "Turning off the relay through the arbiter"
COMMUTATION_26 = "Turning the relay through the arbiter"
COMMUTATION_27 = "Turning the relay through a physical lock"
COMMUTATION_28 = "Turning off the relay through a physical lock"
COMMUTATION_29 = "Full loss of power supply"

# for 0.0.96.11.3.255 События программирования параметров ПУ ГОСТ Р 58940—2020 таблица Д.4
PROGRAMING_1 = "Changing the address or the RS-485-1 exchange rate"
PROGRAMING_2 = "Changing the address or the RS-485-2 exchange rate"
PROGRAMING_3 = "Setting the time"
PROGRAMING_4 = "Changing Daylight Saving time settings"
PROGRAMING_5 = "Changing the seasonal profile of the tariff schedule"
PROGRAMING_6 = "Changing the weekly profile of the tariff schedule"
PROGRAMING_7 = "Changing the day profile of the tariff schedule"
PROGRAMING_8 = "Changing the activation date of the tariff schedule"
PROGRAMING_9 = "Activation of the tariff schedule"
PROGRAMING_10 = "Changing the billing day-hour"
PROGRAMING_11 = "Changing the display mode parameters"
PROGRAMING_12 = "Changing the display mode auto-switch"
PROGRAMING_13 = "Changing a low-security read-only password"
PROGRAMING_14 = "Changing the high-security password on the record"
PROGRAMING_15 = "Changing accounting point data"
PROGRAMING_16 = "Change in the current conversion factor"
PROGRAMING_17 = "Change in the voltage transformation coefficient"
PROGRAMING_18 = "Changing the line parameters for calculating power line losses"
PROGRAMING_19 = "Changing the power limit for disconnection"
PROGRAMING_20 = "Changing the power-off time interval"
PROGRAMING_21 = "Changing the time interval for switching off when the maximum current is exceeded"
PROGRAMING_22 = "Changing the time interval for switching off at the maximum voltage"
PROGRAMING_23 = "Changing the time interval for switching off due to the influence of a magnetic field"
PROGRAMING_24 = "Changing the threshold for fixing a power break"
PROGRAMING_25 = "Changing the threshold for fixing the overvoltage"
PROGRAMING_26 = "Changing the threshold for fixing the voltage drop"
PROGRAMING_27 = "Changing the threshold for fixing the excess of the tangent"
PROGRAMING_28 = "Changing the threshold for fixing the stress asymmetry coefficient"
PROGRAMING_29 = "Changing the matched voltage"
PROGRAMING_30 = "Changing the peak power integration interval"
PROGRAMING_31 = "Changing the capture period of profile PROGRAMING_1 ="
PROGRAMING_32 = "Changing the capture period of profile 2"
PROGRAMING_33 = "Changing the LCD backlight mode"
PROGRAMING_34 = "Changing the telemetry mode 1"
PROGRAMING_35 = "Cleaning the monthly log"
PROGRAMING_36 = "Clearing the daily log"
PROGRAMING_37 = "Clearing the voltage log"
PROGRAMING_38 = "Clearing the current log"
PROGRAMING_39 = "Clearing the on/off log"
PROGRAMING_40 = "Clearing the external impact log"
PROGRAMING_41 = "Clearing the connection log"
PROGRAMING_42 = "Clearing the unauthorized access log"
PROGRAMING_43 = "Clearing the network quality log"
PROGRAMING_44 = "Clearing the tangent log"
PROGRAMING_45 = "Clearing the I/O log"
PROGRAMING_46 = "Clearing profile 1"
PROGRAMING_47 = "Clearing profile 2"
PROGRAMING_48 = "Clearing profile 3"
PROGRAMING_49 = "Changing the special Days table"
PROGRAMING_50 = "Changing the relay control mode"
PROGRAMING_51 = "Recording of readings in the monthly log"
PROGRAMING_52 = "Changing the initiative exit mode"
PROGRAMING_53 = "Changing the unicast key for low security"
PROGRAMING_54 = "Changing the broadcast encryption key for low security"
PROGRAMING_55 = "Changing the unicast key for high security"
PROGRAMING_56 = "Changing the broadcast key for high security"
PROGRAMING_57 = "Changing the authentication key for high security"
PROGRAMING_58 = "Changing the master key"
PROGRAMING_59 = "Change the conversion level for low secrecy"
PROGRAMING_60 = "Change the conversion level for high security"
PROGRAMING_61 = "Changing the remote display number"
PROGRAMING_62 = "Changing the active energy metering mode modulo or separately in two directions"
PROGRAMING_63 = "Setting the time by GPS/GLONASS"
PROGRAMING_64 = "Changing the neutral break-off mode"
PROGRAMING_65 = "Software Update"
PROGRAMING_66 = "Changing the current unbalance shutdown mode"
PROGRAMING_67 = "Changing the temperature shutdown mode"
PROGRAMING_68 = "Time correction"
PROGRAMING_69 = "Changing the authentication key for low security"
PROGRAMING_70 = "Clearing Initiative exit flags"
PROGRAMING_71 = "Changing the timeout for an HDLC connection"
PROGRAMING_72 = "Changing the hours of heavy loads"
PROGRAMING_73 = "Changing the maximum monitoring hours"
PROGRAMING_74 = "Changing the connection scheme"
PROGRAMING_75 = "Changing the telemetry mode 2"
PROGRAMING_76 = "Changing the telemetry mode 3"
PROGRAMING_77 = "Changing the telemetry mode 4"
PROGRAMING_78 = "Changing the shutdown mode when opening the terminal cover or housing"
PROGRAMING_79 = "Changing the active communication profile setting for communication ports"
PROGRAMING_80 = "Clearing the network quality log on a monthly interval"
PROGRAMING_81 = "Changing the interval for integrating network parameters"
PROGRAMING_82 = "Changing the threshold value over time. Reactive power factor tg <p average for all phases"
PROGRAMING_83 = "Changing the threshold value over time. Differential current. % of the maximum current value"
PROGRAMING_84 = "Changing the threshold value over time. The coefficient of asymmetry in the reverse sequence"
PROGRAMING_85 = "Changing the address or exchange rate Optical port P1"
PROGRAMING_86 = "Changing the address or exchange rate Port P4"
PROGRAMING_87 = "Changing the filter of events of shutdown of the load relay"
PROGRAMING_88 = "Changing the monitor of events of the load relay"
PROGRAMING_89 = "Changing the setting of energy accounting"
PROGRAMING_90 = "Changing the threshold value of frequency deviations"
PROGRAMING_91 = "Changing the threshold value of active power control at the integration interval"
PROGRAMING_92 = "Changing the threshold value of active power control at the integration interval during peak loads"
PROGRAMING_93 = "Changing the time of fixing the foot frame. Fixation of the foot frame"
PROGRAMING_94 = "Monitor of the events of the load relay"
PROGRAMING_95 = "Alarm relay monitor 1"
PROGRAMING_96 = "Alarm relay monitor 2"
PROGRAMING_97 = "Alarm relay monitor 3"
PROGRAMING_98 = "Alarm relay monitor 4"
PROGRAMING_99 = "Changing the parameters of the arbiter of the load relay"
PROGRAMING_100 = "Changing the parameters of the arbiter of the alarm relay 1"
PROGRAMING_101 = "Changing the parameters of the arbiter of the alarm relay 2"
PROGRAMING_102 = "Changing the parameters of the arbiter of the alarm relay 3"
PROGRAMING_103 = "Changing the parameters of the arbiter of the alarm relay 4"
PROGRAMING_104 = "Changing the filter of events of the signaling relay 1"
PROGRAMING_105 = "Changing the filter of events of the signaling relay 2"
PROGRAMING_106 = "Changing the filter of events of the signaling relay 3"
PROGRAMING_107 = "Changing the filter of events of the signaling relay 4"
PROGRAMING_108 = "Changing the control mode of the alarm relay 1"
PROGRAMING_109 = "Changing the control mode of the alarm relay 2"
PROGRAMING_110 = "Changing the control mode of the alarm relay 3"
PROGRAMING_111 = "Changing the control mode of the alarm relay 4"
PROGRAMING_112 = "Change type of contact of the signaling relayChange type of contact of the signaling relay"
PROGRAMING_113 = "Changing the timeout for TCP/UDP connection (optical port P1)"
PROGRAMING_114 = "Changing the timeout for TCP/UDP connection (port P1)"
PROGRAMING_115 = "Changing the timeout for TCP/UDP connection (port P1)"
PROGRAMING_116 = "Changing the timeout for TCP/UDP connection (port P1)"
PROGRAMING_117 = "Cleaning the log 'Tangens output for the threshold at the integration interval'"
PROGRAMING_118 = "Cleaning the log 'Correction of Time'"
PROGRAMING_119 = "Cleaning the log 'At the beginning of the year'"
PROGRAMING_120 = "reserved"
PROGRAMING_121 = "Cleaning the log 'Power Control'"
PROGRAMING_122 = "Cleaning the log 'Battery'"
PROGRAMING_123 = "Cleaning the log 'Control of the Load Relay Relay'"
PROGRAMING_124 = "Cleaning the log 'Temperature control'"
PROGRAMING_125 = "Cleaning the log 'Deviation of phase A voltage'"
PROGRAMING_126 = "Cleaning the log 'Deviation of phase B voltage'"
PROGRAMING_127 = "Cleaning the log 'Deviation of phase C voltage'"
PROGRAMING_128 = "Cleaning the log 'Deviation of linear voltage AB'"
PROGRAMING_129 = "Cleaning the log 'Deviation of linear voltage BC'"
PROGRAMING_130 = "Cleaning the log 'Deviation of linear voltage CA'"
PROGRAMING_131 = "Cleaning the log 'Voltage Excess'"
PROGRAMING_132 = "Cleaning the log 'Interruption of voltage'"
PROGRAMING_133 = "Cleaning the log 'Television signaling'"
PROGRAMING_134 = "Cleaning the log 'Network situation'"
PROGRAMING_135 = "Changing the voltage threshold by zero sequence, time until the event is triggered, sec (Networks abnormal)"
PROGRAMING_136 = "Changing the voltage threshold through the zero sequence, the time of delaying the installation of the Push event, sec (the abnormal network situation)"
PROGRAMING_137 = "Changing the voltage threshold, minimum value, V (an emergency situations)"
PROGRAMING_138 = "Changing the voltage threshold, time before the event is triggered, sec (the abnormal network situation)"
PROGRAMING_139 = "Changing the voltage threshold, time delaying the installation of the Push event, sec (the abnormal network situation)"
PROGRAMING_140 = "Changing the voltage threshold by reverse sequence, maximum value, V (the abnormal network situation)"
PROGRAMING_141 = "Changing the voltage threshold by reverse sequence, time until the event is triggered, sec (an emergency system of the network)"
PROGRAMING_142 = "Changing the voltage threshold by the reverse sequence, the time of delaying the installation of the Push event, sec (the abnormal network situation)"
PROGRAMING_143 = "Pressing electronic seals"
PROGRAMING_144 = "Cleaning fixation of the effects of magnetic and/or HF fields"
PROGRAMING_145 = "Changing the clock belt"
PROGRAMING_146 = "Changing the sequence of the output to LCD in the 'Auto-Carrot' mode"
PROGRAMING_147 = "Changing the sequence of the output to LCD in the 'button' mode"
PROGRAMING_148 = "Changing the level of the current limit"
PROGRAMING_149 = "Changing the level of the voltage limit"
PROGRAMING_150 = "Emergency tariff number"
PROGRAMING_1024 = "KPZ. Change device parameters"

# for 0.0.96.11.4.255 События внешних воздействий ГОСТ Р 58940—2020 таблица Д.5
EXTERNAL_IMPACT_1 = "Magnetic field - the beginning"
EXTERNAL_IMPACT_2 = "Magnetic field - ending"
EXTERNAL_IMPACT_3 = "Cleansing the electronic seal cover"
EXTERNAL_IMPACT_4 = "Plugging of the electoral seal"
EXTERNAL_IMPACT_5 = "Proceeding the electronic seal of the outer sensor"
EXTERNAL_IMPACT_6 = "The impact of HF fields - beginning"
EXTERNAL_IMPACT_7 = "The impact of HF fields - ending"

# for 0.0.96.11.5.255 Коммуникационные события ГОСТ Р 58940—2020 таблица Д.6
COMMUNICATION_1 = "Connection terminated interface"
COMMUNICATION_2 = "Connection established interface"

# for 0.0.96.11.6.255 События контроля доступа ГОСТ Р 58940—2020 таблица Д.7
ACCESS_1 = "Unauthorized access attempt interface"
ACCESS_2 = "Violation of the protocol requirements"
ACCESS_3 = "Blocking for exceeding the number of incorrect passwords"
ACCESS_4 = "Firmware verification error"

# for 0.0.96.11.7.255 Коды событий для журнала самодиагностики ГОСТ Р 58940—2020 таблица Д.8
SELF_DIAGNOSTIC_1 = "Initializing the Device"
SELF_DIAGNOSTIC_2 = "Measuring unit-error"
SELF_DIAGNOSTIC_3 = "Measuring unit-OK"
SELF_DIAGNOSTIC_4 = "Computing block-error"
SELF_DIAGNOSTIC_5 = "Real-time clock-error"
SELF_DIAGNOSTIC_6 = "Real-time clock-OK"
SELF_DIAGNOSTIC_7 = "Power supply unit-error"
SELF_DIAGNOSTIC_8 = "Power supply unit-OK"
SELF_DIAGNOSTIC_9 = "Display-error"
SELF_DIAGNOSTIC_10 = "Display-OK"
SELF_DIAGNOSTIC_11 = "Memory block-error"
SELF_DIAGNOSTIC_12 = "Memory block-OK"
SELF_DIAGNOSTIC_13 = "Program memory block-error"
SELF_DIAGNOSTIC_14 = "Program memory block-OK"
SELF_DIAGNOSTIC_15 = "Core clocking system-error"
SELF_DIAGNOSTIC_16 = "Core clocking system-OK"
SELF_DIAGNOSTIC_17 = "Clock clocking system-error"
SELF_DIAGNOSTIC_18 = "Clock clocking system-OK"
SELF_DIAGNOSTIC_19 = "Computing unit-OK"

# for 0.0.96.11.8.255 События по превышению реактивной мощности tg ф тангенс сети ГОСТ Р 58940—2020 таблица Д.9
REACTIVE_POWER_1 = "Exceeding the set threshold is the beginning"
REACTIVE_POWER_2 = "Exceeding the set threshold — end"

# for 0.0.96.5.1.255 Статус качества сети профиль суточных показаний
POWER_QUALITY1_1 = "Deviation of voltage by more than 10% of the nominal"
POWER_QUALITY1_2 = "Frequency deviation by more than 0.4 Hz from the nominal"

# for POWER_QUALITY1_0 =.0.96.5.4.255 Статус качества сети журнал качества сети
POWER_QUALITY2_1 = "Reducing the voltage of more than 10%"
POWER_QUALITY2_8 = "Raising voltage for more than 10%"
POWER_QUALITY2_0x10 = "Reducing the frequency of more than 0.4 Hz"
POWER_QUALITY2_0x20 = "Reducing the frequency of more than 0.2 Hz"
POWER_QUALITY2_0x40 = "Increase frequency more than 0.2 Hz"
POWER_QUALITY2_0x80 = "Increase frequency more than 0.4 Hz"
POWER_QUALITY2_0x4000 = "Reducing the frequency of more than a given threshold"
POWER_QUALITY2_0x8000 = "Increase frequency more than a given threshold"
